@@ -181,7 +181,8 @@ sub cTrees {
                             'oidcOPMetaDataOptionsJWKSTimeout',
                             'oidcOPMetaDataOptionsClientID',
                             'oidcOPMetaDataOptionsClientSecret',
-                            'oidcOPMetaDataOptionsStoreIDToken'
+                            'oidcOPMetaDataOptionsStoreIDToken',
+                            'oidcOPMetaDataOptionsUserAttribute',
                         ]
                     },
                     {
@@ -262,7 +263,6 @@ sub cTrees {
                             'oidcRPMetaDataOptionsAllowOffline',
                             'oidcRPMetaDataOptionsAllowPasswordGrant',
                             'oidcRPMetaDataOptionsAllowClientCredentialsGrant',
-                            'oidcRPMetaDataOptionsRequestUris',
                             'oidcRPMetaDataOptionsAuthnLevel',
                             'oidcRPMetaDataOptionsRule',
                         ]
@@ -335,11 +335,19 @@ sub cTrees {
                 nodes => [
                     'casAppMetaDataOptionsService',
                     'casAppMetaDataOptionsUserAttribute',
+                    'casAppMetaDataOptionsLogout',
                     'casAppMetaDataOptionsAuthnLevel',
                     'casAppMetaDataOptionsRule',
                     'casAppMetaDataOptionsComment',
                 ]
             },
+            {
+                title => 'casAppMetaDataOptionsDisplay',
+                form  => 'simpleInputContainer',
+                nodes => [
+                    'casAppMetaDataOptionsDisplayName',
+                ],
+            },
             'casAppMetaDataMacros',
         ],
     };
