@@ -48,11 +48,18 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsUserAttribute",
             "title" : "casAppMetaDataOptionsUserAttribute"
          },
+         {
+            "default" : -1,
+            "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsLogout",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsLogout",
+            "title" : "casAppMetaDataOptionsLogout",
+            "type" : "trool"
+         },
          {
             "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAuthnLevel",
             "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsAuthnLevel",
             "title" : "casAppMetaDataOptionsAuthnLevel",
-            "type" : "int"
+            "type" : "intOrNull"
          },
          {
             "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsRule",
@@ -70,6 +77,18 @@ function templates(tpl,key) {
       "title" : "casAppMetaDataOptions",
       "type" : "simpleInputContainer"
    },
+   {
+      "_nodes" : [
+         {
+            "get" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsDisplayName",
+            "id" : tpl+"s/"+key+"/"+"casAppMetaDataOptionsDisplayName",
+            "title" : "casAppMetaDataOptionsDisplayName"
+         }
+      ],
+      "id" : "casAppMetaDataOptionsDisplay",
+      "title" : "casAppMetaDataOptionsDisplay",
+      "type" : "simpleInputContainer"
+   },
    {
       "cnodes" : tpl+"s/"+key+"/"+"casAppMetaDataMacros",
       "default" : [],
@@ -174,7 +193,7 @@ function templates(tpl,key) {
             "get" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSortNumber",
             "id" : tpl+"s/"+key+"/"+"casSrvMetaDataOptionsSortNumber",
             "title" : "casSrvMetaDataOptionsSortNumber",
-            "type" : "int"
+            "type" : "intOrNull"
          }
       ],
       "id" : "casSrvMetaDataOptionsDisplay",
@@ -262,6 +281,11 @@ function templates(tpl,key) {
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
                   "title" : "oidcOPMetaDataOptionsStoreIDToken",
                   "type" : "bool"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserAttribute",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserAttribute",
+                  "title" : "oidcOPMetaDataOptionsUserAttribute"
                }
             ],
             "id" : "oidcOPMetaDataOptionsConfiguration",
@@ -409,7 +433,7 @@ function templates(tpl,key) {
             "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsSortNumber",
             "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsSortNumber",
             "title" : "oidcOPMetaDataOptionsSortNumber",
-            "type" : "int"
+            "type" : "intOrNull"
          }
       ],
       "help" : "authopenidconnect.html#display",
@@ -465,16 +489,6 @@ function templates(tpl,key) {
             "title" : "email",
             "type" : "oidcAttribute"
          },
-         {
-            "data" : [
-               "sn",
-               "string",
-               "auto"
-            ],
-            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataExportedVars/family_name",
-            "title" : "family_name",
-            "type" : "oidcAttribute"
-         },
          {
             "data" : [
                "cn",
@@ -484,6 +498,16 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataExportedVars/name",
             "title" : "name",
             "type" : "oidcAttribute"
+         },
+         {
+            "data" : [
+               "uid",
+               "string",
+               "auto"
+            ],
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataExportedVars/preferred_username",
+            "title" : "preferred_username",
+            "type" : "oidcAttribute"
          }
       ],
       "help" : "idpopenidconnect.html#exported-attributes",
@@ -570,7 +594,7 @@ function templates(tpl,key) {
          {
             "_nodes" : [
                {
-                  "default" : "HS512",
+                  "default" : "RS256",
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIDTokenSignAlg",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIDTokenSignAlg",
                   "select" : [
@@ -696,16 +720,11 @@ function templates(tpl,key) {
                   "title" : "oidcRPMetaDataOptionsAllowClientCredentialsGrant",
                   "type" : "bool"
                },
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRequestUris",
-                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRequestUris",
-                  "title" : "oidcRPMetaDataOptionsRequestUris"
-               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
                   "title" : "oidcRPMetaDataOptionsAuthnLevel",
-                  "type" : "int"
+                  "type" : "intOrNull"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
@@ -723,25 +742,25 @@ function templates(tpl,key) {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthorizationCodeExpiration",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthorizationCodeExpiration",
                   "title" : "oidcRPMetaDataOptionsAuthorizationCodeExpiration",
-                  "type" : "int"
+                  "type" : "intOrNull"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIDTokenExpiration",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIDTokenExpiration",
                   "title" : "oidcRPMetaDataOptionsIDTokenExpiration",
-                  "type" : "int"
+                  "type" : "intOrNull"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenExpiration",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenExpiration",
                   "title" : "oidcRPMetaDataOptionsAccessTokenExpiration",
-                  "type" : "int"
+                  "type" : "intOrNull"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsOfflineSessionExpiration",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsOfflineSessionExpiration",
                   "title" : "oidcRPMetaDataOptionsOfflineSessionExpiration",
-                  "type" : "int"
+                  "type" : "intOrNull"
                }
             ],
             "id" : "oidcRPMetaDataOptionsTimeouts",
@@ -772,6 +791,10 @@ function templates(tpl,key) {
                      {
                         "k" : "front",
                         "v" : "Front Channel"
+                     },
+                     {
+                        "k" : "back",
+                        "v" : "Back Channel"
                      }
                   ],
                   "title" : "oidcRPMetaDataOptionsLogoutType",
@@ -1207,7 +1230,7 @@ function templates(tpl,key) {
             "get" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsSortNumber",
             "id" : tpl+"s/"+key+"/"+"samlIDPMetaDataOptionsSortNumber",
             "title" : "samlIDPMetaDataOptionsSortNumber",
-            "type" : "int"
+            "type" : "intOrNull"
          }
       ],
       "help" : "authsaml.html#display",
@@ -1422,7 +1445,7 @@ function templates(tpl,key) {
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsAuthnLevel",
                   "id" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsAuthnLevel",
                   "title" : "samlSPMetaDataOptionsAuthnLevel",
-                  "type" : "int"
+                  "type" : "intOrNull"
                },
                {
                   "get" : tpl+"s/"+key+"/"+"samlSPMetaDataOptionsRule",
@@ -1576,7 +1599,7 @@ function templates(tpl,key) {
             "get" : tpl+"s/"+key+"/"+"vhostAuthnLevel",
             "id" : tpl+"s/"+key+"/"+"vhostAuthnLevel",
             "title" : "vhostAuthnLevel",
-            "type" : "int"
+            "type" : "intOrNull"
          },
          {
             "default" : "Main",
